@@ -99,7 +99,7 @@ static const tile computerWonFarPattern[4][6] =
 
 - (void) initBoardConstants
 {
-    int startRow, startColumn, row, column, position, value; 
+    int startRow, startColumn, position; 
 
     boardConstants = calloc (size * size, sizeof (int));
 
@@ -163,16 +163,17 @@ static const tile computerWonFarPattern[4][6] =
       }
 }
 
-- (oneway void) dealloc
+- (void) dealloc
 {
-    free (board);
-    free (boardConstants);
+  free (board);
+  free (boardConstants);
+  [super dealloc];
 }
 
 // Initialize, reset, set level
 - (void) reset
 {
-  int i, j, v;
+  int i, j;
 
   for (i = 0; i < size; i++)
     for (j = 0; j < size; j++)
